@@ -300,8 +300,8 @@ print_help (void)
 
   print_usage ();
 
-  printf (_(UT_HELP_VRSN));
-  printf (_(UT_EXTRA_OPTS));
+  printf (UT_HELP_VRSN);
+  printf (UT_EXTRA_OPTS);
 
   printf (" %s\n", "-p");
   printf ("    %s\n", _("Optional port of which to connect"));
@@ -312,19 +312,15 @@ print_help (void)
   printf (" %s\n", "-pf");
   printf ("    %s\n", _("Field number in raw qstat output that contains ping time"));
 
-  printf (_(UT_TIMEOUT), DEFAULT_SOCKET_TIMEOUT);
+  printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
 
   printf ("\n");
   printf ("%s\n", _("Notes:"));
   printf (" %s\n", _("This plugin uses the 'qstat' command, the popular game server status query tool."));
   printf (" %s\n", _("If you don't have the package installed, you will need to download it from"));
   printf (" %s\n", _("http://www.activesw.com/people/steve/qstat.html before you can use this plugin."));
-#ifdef NP_EXTRA_OPTS
-  printf ("\n");
-  printf (_(UT_EXTRA_OPTS_NOTES));
-#endif
 
-  printf (_(UT_SUPPORT));
+  printf (UT_SUPPORT);
 }
 
 
@@ -332,8 +328,8 @@ print_help (void)
 void
 print_usage (void)
 {
-  printf (_("Usage:"));
-  printf (" %s <game> <ip_address> [-p port] [-gf game_field] [-mf map_field] [-pf ping_field]\n", progname);
+  printf ("%s\n", _("Usage:"));
+  printf (" %s [-hvV] [-P port] [-t timeout] [-g game_field] [-m map_field] [-p ping_field] [-G game-time] [-H hostname] <game> <ip_address>\n", progname);
 }
 
 /******************************************************************************
